@@ -103,8 +103,7 @@ def joined_string(fmt_call: ast.Call) -> ast.JoinedStr:
         if sys.version_info < (3, 8):
             return isinstance(node, ast.Str)
         else:
-            return (isinstance(node, ast.Constant) and
-                    isinstance(node.value, str))
+            return isinstance(node, ast.Constant) and isinstance(node.value, str)
 
     def literal_string_value(node):
         if sys.version_info < (3, 8):
@@ -113,15 +112,19 @@ def joined_string(fmt_call: ast.Call) -> ast.JoinedStr:
             return node.value
 
     def fix_literals(segment):
-        if (isinstance(segment, ast.FormattedValue) and
-                segment.format_spec is None and
-                is_literal_string(segment.value)):
+        if (
+            isinstance(segment, ast.FormattedValue)
+            and segment.format_spec is None
+            and is_literal_string(segment.value)
+        ):
             return segment.value
         return segment
+
     new_segments = [fix_literals(e) for e in new_segments]
 
-    if all(is_literal_string(segment)
-           for segment in new_segments):
-        return ast.Str(''.join(literal_string_value(segment) for segment in new_segments))
+    if all(is_literal_string(segment) for segment in new_segments):
+        return ast.Str(
+            "".join(literal_string_value(segment) for segment in new_segments)
+        )
 
     return ast.JoinedStr(new_segments)
