@@ -13,8 +13,8 @@ FORMAT_GROUP_MATCH = f"[hlL]?([{FORMATS}])"
 
 PREFIX_GROUP = "[0-9]*[.]?[0-9]*"
 
-DICT_PATTERN = re.compile(rf"(%{PREFIX_GROUP}\([^)]+\){FORMAT_GROUP})")
-SPLIT_DICT_PATTERN = re.compile(rf"%({PREFIX_GROUP})\(([^)]+)\){FORMAT_GROUP_MATCH}")
+DICT_PATTERN = re.compile(rf"(%\([^)]+\){PREFIX_GROUP}{FORMAT_GROUP})")
+SPLIT_DICT_PATTERN = re.compile(rf"%\(([^)]+)\)({PREFIX_GROUP}){FORMAT_GROUP_MATCH}")
 VAR_KEY_PATTERN = re.compile(
     f"%({PREFIX_GROUP}){FORMAT_GROUP_MATCH}"
 )  # specs at https://docs.python.org/3/library/stdtypes.html#string-formatting
@@ -22,12 +22,12 @@ obsolete_specifiers = "hlL"
 
 translate_conversion_types = {"i": "d", "u": "d"}
 conversion_methods = {"r": "!r", "a": "!a", "s": None}
-integer_specificers = 'dxXob'
+integer_specificers = "dxXob"
 
 
 def formatted_value(fmt_prefix, fmt_spec, val):
     if fmt_spec in integer_specificers:
-        fmt_prefix = fmt_prefix.replace('.', '0')
+        fmt_prefix = fmt_prefix.replace(".", "0")
 
     if fmt_spec in conversion_methods:
         if not state.aggressive and fmt_prefix:
@@ -70,7 +70,7 @@ def transform_dict(node):
     matches = DICT_PATTERN.findall(format_str)
     spec = []
     for idx, m in enumerate(matches):
-        _, prefix, var_key, fmt_str, _ = SPLIT_DICT_PATTERN.split(m)
+        _, var_key, prefix, fmt_str, _ = SPLIT_DICT_PATTERN.split(m)
         if not var_key:
             raise FlyntException("could not find dict key")
         spec.append((prefix, var_key, fmt_str))
@@ -181,7 +181,7 @@ supported_operands = [
     ast.Subscript,
     ast.Call,
     ast.BinOp,
-    ast.IfExp
+    ast.IfExp,
 ]
 
 
